@@ -2,6 +2,8 @@ package Sim::OPT::Descend;
 # This is the module Sim::OPT::Descend of Sim::OPT, a program for detailed metadesign managing parametric explorations, distributed under a dual licence, open-source (GPL v3) and proprietary.
 # Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
+our $descend = bless( {}, "Sim::OPT::Descend" );
+
 use Math::Trig;
 use Math::Round;
 use List::Util qw[ min max reduce shuffle];
@@ -171,9 +173,9 @@ sub descend
   my $countblock = $d{countblock}; say  "HERE IN DESCEND \$countblock: " . dump( $countblock );
   my %incumbents = %{ $d{incumbents} }; #say  "HERE IN DESCEND \%incumbents: " . dump( \%incumbents );
   my @varnumbers = @{ $d{varnumbers} };
-  @varnumbers = Sim::OPT::washn( @varnumbers ); #say  "HERE IN DESCEND \@varnumbers: " . dump( @varnumbers );
+  @varnumbers = $opt->washn( @varnumbers ); #say  "HERE IN DESCEND \@varnumbers: " . dump( @varnumbers );
   my @miditers = @{ $d{miditers} };
-  @miditers = Sim::OPT::washn( @miditers ); #say  "HERE IN DESCEND \@miditers: " . dump( @miditers );
+  @miditers = $opt->washn( @miditers ); #say  "HERE IN DESCEND \@miditers: " . dump( @miditers );
   my @sweeps = @{ $d{sweeps} }; #say  "HERE IN DESCEND \@sweeps: " . dump( @sweeps );
   my @sourcesweeps = @{ $d{sourcesweeps} }; #say  "HERE IN DESCEND \@sourcesweeps: " . dump( @sourcesweeps );
   my @rootnames = @{ $d{rootnames} }; #say  "HERE IN DESCEND \@rootnames: " . dump( @rootnames );
@@ -189,8 +191,8 @@ sub descend
 	my @blockelts = @{ $d{blockelts} };
 
 	my @blocks = @{ $d{blocks} };
-  my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase);
-  $rootname = Sim::OPT::clean( $rootname, $mypath, $file );
+  my $rootname = $opt->getrootname(\@rootnames, $countcase);
+  $rootname = $opt->clean( $rootname, $mypath, $file );
   my %varnums = %{ $d{varnums} };
   my %mids = %{ $d{mids} };
   my %carrier = %{ $d{carrier} };
@@ -307,7 +309,7 @@ sub descend
 
   if ( ( not ( $fire eq "y" ) ) and ( ( $dowhat{ga} eq "y" ) or ( $dowhat{randompick} eq "y" ) ) )
   {
-    Sim::OPT::washduplicates( $repfile );
+    $opt->washduplicates( $repfile );
   }
   
 
@@ -353,7 +355,7 @@ sub descend
 
   #if ( $winning ne "" )
   #{
-  #  Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+  #  $opt->callblock( { countcase => $countcase, countblock => $countblock,
   #  miditers => \@miditers,  winneritems => \@winneritems,
   #  dirfiles => \%dirfiles, varnumbers => \@varnumbers,
   #  sweeps => \@sweeps, incumbents => \%incumbents, dowhat => \%dowhat ,
@@ -408,7 +410,7 @@ sub descend
 
     #say  "IN DESCENT \@blockelts " . dump( @blockelts );
     ####HERE!!!
-    my $expected_r = Sim::OPT::enumerate(\%varnums, \@blockelts, $from); say  "IN DESCENT \$countblock $countblock \$expected_r " . dump( $expected_r );
+    my $expected_r = $opt->enumerate(\%varnums, \@blockelts, $from); say  "IN DESCENT \$countblock $countblock \$expected_r " . dump( $expected_r );
     
     
     my %present;
@@ -423,7 +425,7 @@ sub descend
       chomp $ln;
       next if $ln =~ /^\s*$/;
       ####HERE!!!
-      my $rid = Sim::OPT::instid( $ln, $file ); say  "IN DESCEND \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
+      my $rid = $opt->instid( $ln, $file ); say  "IN DESCEND \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
       if ( defined($rid) and $rid ne "" )
       {
         #$dirfiles{reps}{$rid} = $ln; say  "IN DESCEND WRITING \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps}{$rid} );# NOT $repfile
@@ -467,7 +469,7 @@ sub descend
         my @elts = split(/,/, $line); #say  "ELTS: " . dump( @elts );
         my $touse = $elts[0];
 
-        $touse = Sim::OPT::clean( $touse, $mypath, $file );
+        $touse = $opt->clean( $touse, $mypath, $file );
 
         if ( ( ( $dowhat{names} eq "short" ) or ( $dowhat{names} eq "medium" ) ) and ( $touse =~ /^\d+$/ ) )
         {
@@ -1379,14 +1381,14 @@ sub metamodel
 
   if ( defined( $treaty ) and ( $treaty eq "cue" ) )
   {
-    require Sim::OPTcue;
-    return Sim::OPTcue::gometamodel(
+    require( Sim::OPTcue );
+    return( $optcue->gometamodel(
       $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
       $direction, $starorder, $ordmeta, $varnums_r, $countblock
-    );
+    ) );
   }
 
-  return( Sim::OPTcue::changemetachannel(
+  return( $optcue->changemetachannel(
     $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
     $direction, $starorder, $ordmeta, $varnums_r, $countblock
   ) );
@@ -1466,7 +1468,7 @@ sub metamodel
     my $winneritem = $winnerelms[0]; #say  "!!! \$winneritem: $winneritem";
 
     #say  "HERE WINNERITEM BEFORE CLEANING: $winneritem.";
-    $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file );
+    $winneritem = $opt->clean( $winneritem, $mypath, $file );
     #say  "HERE WINNERITEM AFTER CLEANING: $winneritem.";
     push ( @{ $incumbents{$closingelt} }, $winneritem );
 
@@ -1680,7 +1682,7 @@ sub metamodel
         my $metafile = $sortmixed . "_meta.csv";
         my $ordmeta = $sortmixed . "_ordmeta.csv";
 
-        my @blockelts = @{ Sim::OPT::getblockelts( \@sweeps, $countcase, $countblock ) }; #say  "IN callblock \@blockelts " . dump( @blockelts );
+        my @blockelts = @{ $opt->getblockelts( \@sweeps, $countcase, $countblock ) }; #say  "IN callblock \@blockelts " . dump( @blockelts );
 
         metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile,
           $direction, $starorder, $ordmeta, \%varnums, $countblock );
@@ -1765,14 +1767,14 @@ sub metamodel
               if ( $dowhat{morph} eq "y" )
               {
                 say  "#Calling morphing operations for instance $instance{is} in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-                my @result = Sim::OPT::Morph::morph( $configfile, \@instancees, \%dirfiles, \%dowhat, \%vehicles, \%inst );
+                my @result = $morph->morph( $configfile, \@instancees, \%dirfiles, \%dowhat, \%vehicles, \%inst );
               }
  
               my( $packet_r, $dirfiles_r );
               if ( ( $dowhat{simulate} eq "y" ) or ( $dowhat{newreport} eq "y" ) )
               {
                 say  "#Calling simulations, reporting and retrieving for instance $instance{is} in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-                ( $packet_r, $dirfiles_r, $csim ) = Sim::OPT::Sim::sim(
+                ( $packet_r, $dirfiles_r, $csim ) = $sim->sim(
                     { instances => \@instancees, dirfiles => \%dirfiles, dowhat => \%dowhat, vehicles => \%vehicles, inst => \%inst } );
                 @packet = uniq( @$packet_r ); say  "RECEIVED PACKET " . dump( @packet );
                 %dirfiles = %$dirfiles;
@@ -1797,7 +1799,7 @@ sub metamodel
 
 
         ###DDDTHIS
-        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file );
+        $winneritem = $opt->clean( $winneritem, $mypath, $file );
 
 
 
@@ -1828,7 +1830,7 @@ sub metamodel
         @varnumbers = @{ dclone( $dirfiles{varnumbershold} ) };
         @miditers = @{ dclone( $dirfiles{miditershold} ) };
         say  "WINNERITEMS: " . dump( @winneritems );
-        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        $opt->callblock( { countcase => $countcase, countblock => $countblock,
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, incumbents => \%incumbents, dowhat => \%dowhat ,
@@ -1842,11 +1844,11 @@ sub metamodel
 
         $countstring++;
         $dirfiles{countstring} = $countstring;
-        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file );
+        $winneritem = $opt->clean( $winneritem, $mypath, $file );
         say  "\$winneritem: " . dump( $winneritem );
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem );
         say  "WINNERITEMS: " . dump( @winneritems );
-        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        $opt->callblock( { countcase => $countcase, countblock => $countblock,
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, incumbents => \%incumbents, dowhat => \%dowhat ,
@@ -1865,7 +1867,7 @@ sub metamodel
         my $metafile = $sortmixed . "_tmp_meta.csv";
         my $ordmeta = $sortmixed . "_ordmeta.csv";
 
-        my @blockelts = @{ Sim::OPT::getblockelts( \@sweeps, $countcase, $countblock ) };
+        my @blockelts = @{ $opt->getblockelts( \@sweeps, $countcase, $countblock ) };
 
         metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile,
           $direction, $starorder, $ordmeta, \%varnums, $countblock );
@@ -1944,14 +1946,14 @@ sub metamodel
               if ( $dowhat{morph} eq "y" )
               {
                 say  "#Calling morphing operations for instance $instance{is} in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-                my @result = Sim::OPT::Morph::morph( $configfile, \@instancees, \%dirfiles, \%dowhat, \%vehicles, \%inst );
+                my @result = $morph->morph( $configfile, \@instancees, \%dirfiles, \%dowhat, \%vehicles, \%inst );
               }
 
               my( $packet_r, $dirfiles_r );
               if ( ( $dowhat{simulate} eq "y" ) or ( $dowhat{newreport} eq "y" ) )
               {
                 #say  "#Calling simulations, reporting and retrieving for instance $instance{is} in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-                ( $packet_r, $dirfiles_r, $csim ) = Sim::OPT::Sim::sim(
+                ( $packet_r, $dirfiles_r, $csim ) = $sim->sim(
                     { instances => \@instancees, dirfiles => \%dirfiles, dowhat => \%dowhat, vehicles => \%vehicles, inst => \%inst } );
                     @packet = uniq( @$packet_r ); say  "RECEIVED PACKET " . dump( @packet );
                     %dirfiles = %$dirfiles;
@@ -1970,7 +1972,7 @@ sub metamodel
         my @winnerelms = split( /,/, $winnerentry );
         my $winneritem = $winnerelms[0];
 
-        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file );
+        $winneritem = $opt->clean( $winneritem, $mypath, $file );
 
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem );
 
@@ -1979,7 +1981,7 @@ sub metamodel
 
         $countblock++; ### !!!        push ( @{ $winneritems[$countcase][$countblock + 1] }, $winneritem );
         say  "WINNERITEMS: " . dump( @winneritems );
-        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        $opt->callblock( { countcase => $countcase, countblock => $countblock,
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, incumbents => \%incumbents, dowhat => \%dowhat,
@@ -1987,13 +1989,13 @@ sub metamodel
       } ### END OF THE PART ABOUT STAR CONFIGURATIONS
       else
       { #say  "!!!! RELAUNCHING WITH INST " . dump( %inst ); 
-        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file );
+        $winneritem = $opt->clean( $winneritem, $mypath, $file );
         say  "!!!! \winneritem: " . dump( @winneritem );
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem );
         say  "!!!! WINNERITEMS: " . dump( @winneritems );
         $countblock++; ### !!!
 
-        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        $opt->callblock( { countcase => $countcase, countblock => $countblock,
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, incumbents => \%incumbents, dowhat => \%dowhat,
