@@ -2,6 +2,7 @@ package Sim::OPT::Report;
 # This is the module Sim::OPT::Retrieve of Sim::OPT, a program for detailed metadesign managing parametric explorations, distributed under a dual licence, open-source (GPL v3) and proprietary.
 # Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
+our $report = bless( {}, "Sim::OPT::Report" );
 
 # use v5.20;
 use Exporter;
@@ -108,8 +109,8 @@ sub newretrieve
   #my $csim = $dt{csim};
 
   @{ $dirfiles{dones} } = uniq( @{ $dirfiles{dones} } );
-  #%inst = %{ Sim::OPT::washhash( \%inst ) }; say  "3 HERE IN OPT SUB CALLBLOCK \%onst: " . dump( \%onst );
-  $inst_ref = Sim::OPT::filterinsts_wnames( \@{ $dirfiles{dones} } , \%inst );
+  #%inst = %{ $opt->washhash( \%inst ) }; say  "3 HERE IN OPT SUB CALLBLOCK \%onst: " . dump( \%onst );
+  $inst_ref = $opt->filterinsts_wnames( \@{ $dirfiles{dones} } , \%inst );
   %inst = %{ $inst_ref }; # REASSIGNMENT!!!!!!
 
 
@@ -121,9 +122,9 @@ sub newretrieve
   my $countblock = $d{countblock}; #say  "HERE IN NEWRETRIEVE \$countblock: " . dump( $countblock );
   my %incumbents = %{ $d{incumbents} }; #say  "HERE IN NEWRETRIEVE \%incumbents: " . dump( \%incumbents );
   my @varnumbers = @{ $d{varnumbers} };
-  @varnumbers = Sim::OPT::washn( @varnumbers ); #say  "HERE IN NEWRETRIEVE \@varnumbers: " . dump( @varnumbers );
+  @varnumbers = $opt->washn( @varnumbers ); #say  "HERE IN NEWRETRIEVE \@varnumbers: " . dump( @varnumbers );
   my @miditers = @{ $d{miditers} };
-  @miditers = Sim::OPT::washn( @miditers ); #say  "HERE IN NEWRETRIEVE \@miditers: " . dump( @miditers );
+  @miditers = $opt->washn( @miditers ); #say  "HERE IN NEWRETRIEVE \@miditers: " . dump( @miditers );
   my @sweeps = @{ $d{sweeps} }; #say  "HERE IN NEWRETRIEVE \@sweeps: " . dump( @sweeps );
 
   my $direction = ${$dowhat{direction}}[$countcase][$countblock]; #say  "HERE IN NEWRETRIEVE \$direction: " . dump( $direction );
@@ -779,7 +780,7 @@ TTT
                   {
                     push ( @{ $dirfiles{retcases} }, $retfile );
                     #say RETLIST "$retfile";
-                  }  @miditers = Sim::OPT::washn( @miditers );
+                  }  @miditers = $opt->washn( @miditers );
                   
                   
                   say  "IN RETRIEVE3 \$countinstance $countinstance";
@@ -1049,9 +1050,9 @@ sub newreport # This function retrieves the results of interest from the texts f
   my $stamp = $d{stamp};
 
   my @varnumbers = @{ $d{varnumbers} };
-  @varnumbers = Sim::OPT::washn( @varnumbers );
+  @varnumbers = $opt->washn( @varnumbers );
   my @miditers = @{ $d{miditers} };
-  @miditers = Sim::OPT::washn( @miditers );
+  @miditers = $opt->washn( @miditers );
   my @sweeps = @{ $d{sweeps} };
 
   my @winneritems = @{ $d{winneritems} };
@@ -1628,7 +1629,7 @@ sub newreport # This function retrieves the results of interest from the texts f
   }
   my $newln = join( ",", @bag );
   
-  my $rid = Sim::OPT::instid( $newln, $file ); say  "IN REPORT \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
+  my $rid = $opt->instid( $newln, $file ); say  "IN REPORT \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
   if ( defined($rid) and $rid ne "" )
   {
     $dirfiles{reps}{$rid} = $newln; say  "IN REPORT  \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps2}{$rid} );# NOT $repfile
